pub struct BulkSendParams {
pub target_queue: String,
pub should_delete: bool,
pub message_identifiers: Vec<MessageIdentifier>,
pub messages_data: Option<Vec<(MessageIdentifier, Vec<u8>)>>,
pub max_position: usize,
}Expand description
Parameters for bulk send operations
Fields
target_queue: Stringshould_delete: boolmessage_identifiers: Vec<MessageIdentifier>messages_data: Option<Vec<(MessageIdentifier, Vec<u8>)>>max_position: usizeImplementations
Sourceimpl BulkSendParams
impl BulkSendParams
Sourcepub fn with_retrieval(
target_queue: String,
should_delete: bool,
message_identifiers: Vec<MessageIdentifier>,
max_position: usize,
) -> Self
pub fn with_retrieval( target_queue: String, should_delete: bool, message_identifiers: Vec<MessageIdentifier>, max_position: usize, ) -> Self
Create parameters for operations that retrieve messages from the queue
Sourcepub fn with_message_data(
target_queue: String,
should_delete: bool,
messages_data: Vec<(MessageIdentifier, Vec<u8>)>,
max_position: usize,
) -> Self
pub fn with_message_data( target_queue: String, should_delete: bool, messages_data: Vec<(MessageIdentifier, Vec<u8>)>, max_position: usize, ) -> Self
Create parameters for operations with pre-fetched message data
Sourcepub fn with_max_position(
target_queue: String,
should_delete: bool,
message_identifiers: Vec<MessageIdentifier>,
max_position: usize,
) -> Self
pub fn with_max_position( target_queue: String, should_delete: bool, message_identifiers: Vec<MessageIdentifier>, max_position: usize, ) -> Self
Create parameters with max position for better processing limits