pub enum ConfigError {
NoConfig(String),
DB,
Sqlx(Error),
}Expand description
Represents an error that can occur while accessing the configuration.
Variants
NoConfig(String): Returned when a specific configuration field is not found.DB: Indicates a database access error.Sqlx: An error propagated from theSQLxcrate.
Example
use thiserror::Error;
#[derive(Debug, Error)]
pub enum ConfigError {
#[error("No such config field: {0}")]
NoConfig(String),
#[error("Can't access db")]
DB,
#[error("Sqlx")]
Sqlx(#[from] sqlx::Error),
}Variants