pub fn try_decode_scalar_async_response<R>(
raw: MessageEnvelope,
) -> Result<R, Error>where
R: ScalarCodec,Expand description
try to decode async response from raw envelope, returns error instead of panic
pub fn try_decode_scalar_async_response<R>(
raw: MessageEnvelope,
) -> Result<R, Error>where
R: ScalarCodec,try to decode async response from raw envelope, returns error instead of panic