handle_connection

Function handle_connection 

pub fn handle_connection(stream: TcpStream)
Function that handles a request stream. The request is processed based on the method and route. The route determines the file path for a GET request.

Args

  • stream - A TcpStream type which basically is a stream of bytes that represents the client request.