pub struct QueueStatisticsService { /* private fields */ }Expand description
Service for getting real queue statistics from Azure Management API
Implementations
Sourceimpl QueueStatisticsService
impl QueueStatisticsService
Sourcepub fn new(
http_client: Client,
config: StatisticsConfig,
azure_ad_config: AzureAdConfig,
) -> Self
pub fn new( http_client: Client, config: StatisticsConfig, azure_ad_config: AzureAdConfig, ) -> Self
Create a new queue statistics service
Sourcepub async fn get_queue_statistics(
&self,
queue_name: &str,
queue_type: &QueueType,
) -> Option<u64>
pub async fn get_queue_statistics( &self, queue_name: &str, queue_type: &QueueType, ) -> Option<u64>
Get real queue statistics from Azure Management API
Sourcepub async fn is_available(&self) -> bool
pub async fn is_available(&self) -> bool
Check if the service is properly configured and ready
Sourcepub async fn get_both_queue_counts(
&self,
queue_name: &str,
) -> (Option<u64>, Option<u64>)
pub async fn get_both_queue_counts( &self, queue_name: &str, ) -> (Option<u64>, Option<u64>)
Get both active and dead letter counts from Azure Management API
Sourcepub fn config(&self) -> &StatisticsConfig
pub fn config(&self) -> &StatisticsConfig
Get the current configuration