BlockingScalarResponse

Struct BlockingScalarResponse 

pub struct BlockingScalarResponse<R: ScalarCodec> { /* private fields */ }
deferred response that sends default on drop if not used

Implementations

Source

impl<R: ScalarCodec> BlockingScalarResponse<R>

pub fn pid(&self) -> PID

Permission: none

get sender’s process ID

pub fn respond(self, response: R) -> Result<(), Error>

Permission: none

send response

pub fn set_response(&mut self, response: R)

Permission: none

set response will be sent on drop if Self::respond is not called