DeferredLendMut

Struct DeferredLendMut 

pub struct DeferredLendMut<M: LendMut> { /* private fields */ }
An encapsulated blocking LendMut message, which can be responded to later during execution. It can be stored, and will return the message when dropped, or the DeferredLendMut::set_response function is called.

Implementations

Source

impl<M: LendMut> DeferredLendMut<M>

pub fn pid(&self) -> PID

Permission: none

Returns the PID of the sender

pub fn body(&self) -> &M

Permission: none

Get a reference to the parsed message body.

pub fn body_mut(&mut self) -> &mut M

Permission: none

Get a mutable reference to the parsed message body.

pub fn set_response(&mut self, response: M::Response)

Permission: none

Get a mutable reference to the parsed message body.