NeedsInput

Struct NeedsInput 

pub struct NeedsInput { /* private fields */ }
More data needs to be received to make progress.

Provide the data to Self::process().

Implementations

Source

impl NeedsInput

pub fn process( self, input: &mut dyn TlsInputBuffer, output: &mut Vec<Vec<u8>>, ) -> Result<ServerHandshake, Error>

Progress the handshake by receiving further data.

The data is obtained via input. Any output produced is appended to output and should be sent to the peer (including if this function returns an error, because the output may contain an alert.)

An error from this function is otherwise fatal to the connection, as it consumes the NeedsInput object.

On success, this returns:

pub fn into_buffered_connection(self) -> ServerConnection

Temporary escape hatch during migration to new API.