Server

Trait Server 

pub trait Server: ServerMessages {
    // Provided method
    fn on_start(&mut self, context: &mut ServerContext<Self>) { ... }
}
A server.

The KeyOS operating system uses the xous kernel, which is a message-passing microkernel. The messages are passed between “servers,” which represent communication endpoints.

This trait, and it’s companion, ServerMessages, provide an idiomatic way for KeyOS to implement the servers that it needs. This trait contains optional hooks, but can be left empty, the ServerMessages trait contains the actual server definition.

Provided Methods

fn on_start(&mut self, context: &mut ServerContext<Self>)

Hook to do stuff with the context once the server is started.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors