pub struct OperationStats {
pub successful: usize,
pub failed: usize,
pub total: usize,
}Expand description
Statistics about Service Bus operations including success and failure counts.
Tracks the performance and outcome of Service Bus operations, providing metrics for monitoring and debugging purposes. Used throughout the system to report operation results.
Examples
use quetty_server::service_bus_manager::OperationStats;
let mut stats = OperationStats::new();
stats.add_success();
stats.add_success();
stats.add_failure();
assert_eq!(stats.successful, 2);
assert_eq!(stats.failed, 1);
assert_eq!(stats.total, 3);
assert_eq!(stats.success_rate(), 2.0 / 3.0);Fields
successful: usizeNumber of successful operations
failed: usizeNumber of failed operations
total: usizeTotal number of operations attempted
Implementations
Sourceimpl OperationStats
impl OperationStats
pub fn new() -> Self
pub fn add_success(&mut self)
pub fn add_failure(&mut self)
pub fn success_rate(&self) -> f64