pub struct Accepted { /* private fields */ }Expand description
Represents a ClientHello message.
The handshake can be progressed by choosing a ServerConfig based on
Accepted::client_hello() and providing it to Accepted::choose_config().
Implementations
Sourceimpl Accepted
impl Accepted
Sourcepub fn client_hello(&self) -> ClientHello<'_>
pub fn client_hello(&self) -> ClientHello<'_>
Get the ClientHello for this connection.
Sourcepub fn choose_config(
self,
config: Arc<ServerConfig>,
output: &mut Vec<Vec<u8>>,
) -> Result<ServerHandshake, Error>
pub fn choose_config( self, config: Arc<ServerConfig>, output: &mut Vec<Vec<u8>>, ) -> Result<ServerHandshake, Error>
Choose a ServerConfig to progress the handshake.
Output to send to the peer is appended to output. Typically, this is the ServerHello,
but it may also be an Alert if an error is returned.
Returns an error if configuration-dependent validation of the received ClientHello message fails.