pub struct DeferredLendMut<M: LendMut> { /* private fields */ }Expand description
An encapsulated blocking LendMut message, which can be responded to
later during execution. It can be stored, and will return the message when
dropped, or the DeferredLendMut::set_response function is called.
Implementations
Sourceimpl<M: LendMut> DeferredLendMut<M>
impl<M: LendMut> DeferredLendMut<M>
Sourcepub fn set_response(&mut self, response: M::Response)
pub fn set_response(&mut self, response: M::Response)
Get a mutable reference to the parsed message body.