pub type MessageDef<S> = (MessageId, fn(&mut S, MessageEnvelope, &mut ServerContext<S>));Expand description
A message that is known to be handled by a server. This is the type returned by the server message registration helpers.
pub type MessageDef<S> = (MessageId, fn(&mut S, MessageEnvelope, &mut ServerContext<S>));A message that is known to be handled by a server. This is the type returned by the server message registration helpers.